ol {
    counter-reset: item;
}
ol li {
    display: block;
    position: relative;
}
ol li:before {
    content: counters(item, ".")".";
    counter-increment: item;
    position: absolute;
    margin-right: 100%;
    right: 10px; /* space between number and text */
}
.wagtail-editorjs-richtext figure {
    margin: 0;
    margin-bottom: 1rem;
    display: flex;
    flex-direction: column;
    padding: 0.5em;
}
.wagtail-editorjs-richtext figure figcaption {
    padding: 0.5rem 0;
    font-size: 0.8rem;
    text-align: center;
    color: #f3f3f3;
    background-color: rgba(0, 0, 0, 0.4);
}
.wagtail-editorjs-richtext :not(figure) > img {
    padding-top: 1rem;
    padding-bottom: 1rem;
}
.wagtail-editorjs-richtext img {
    height: auto;
}
.wagtail-editorjs-richtext img {
    width: 60%;
}
.wagtail-editorjs-richtext figure.stretched img,
.wagtail-editorjs-richtext img.stretched {
    width: 100%;
}

.wagtail-editorjs-richtext .align-content-left {
    text-align: left;
}
.wagtail-editorjs-richtext .align-content-center {
    text-align: center;
}
.wagtail-editorjs-richtext .align-content-right {
    text-align: right;
}

.wagtail-editorjs-richtext img.align-content-left {
    display: block;
    margin-left: 0;
    margin-right: auto;

}

.wagtail-editorjs-richtext img.align-content-right {
    display: block;
    margin-left: auto;
    margin-right: 0;

}

.wagtail-editorjs-richtext img.align-content-center {
    display: block;
    margin-left: auto;
    margin-right: auto;
}

.wagtail-editorjs-richtext table {
    width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
    margin: 0.5rem 0;
}
.wagtail-editorjs-richtext table th,
.wagtail-editorjs-richtext table td {
    padding: 0.5rem;
    border: 1px solid rgba(0, 0, 0, 0.1);
}
.wagtail-editorjs-richtext table th {
    background-color: rgba(0, 0, 0, 0.1);
}
.wagtail-editorjs-richtext table tr:nth-child(even) {
    background-color: rgba(0, 0, 0, 0.01);
}
.wagtail-editorjs-richtext table tr:nth-child(odd) {
    background-color: rgba(0, 0, 0, 0.03);
}

.wagtail-editorjs-richtext .attaches-link {
    display: inline-block;
    padding: 0.5rem;
    margin: 0.5rem 0;
    background-color: rgba(0, 0, 0, 0.4);
    color: #f3f3f3 !important;
    border-radius: 0.25rem;
    text-decoration: none;
    color: inherit;
}